@@ -1,4 +1,4 @@
-/* $Id: rulestxt.c,v 1.3 1998/07/05 16:38:15 sverrehu Exp $ */
+/* $Id: rulestxt.c,v 1.4 2007-06-13 18:29:52 sverrehu Exp $ */
 /**************************************************************************
  *
  *  FILE            rulestxt.c
@@ -49,8 +49,8 @@ char *textRules =
 "@_\n"
 "\n"
 "Comments? Send mail to either of\n"
-"   sverrehu@online.no\n"
-"   gtl@si.sintef.no\n"
+"   shh@thathost.com\n"
+"   glennli@simula.no\n"
 "\n"
 ;
 
