@@ -1,4 +1,4 @@
-/* $Id: xmain.c,v 1.4 1996/08/25 17:55:27 sverrehu Exp $ */
+/* $Id: xmain.c,v 1.5 2007-06-13 18:29:52 sverrehu Exp $ */
 /**************************************************************************
  *
  *  FILE            xmain.c
@@ -49,6 +49,7 @@ static FL_OBJECT  *frmLight[2][MAX_HOLES];
 static char       playerName[2][20] = { "the human player", "the computer" };
 static int        maxPly[2] = { 0, 4 };
 static int        rulesDisplayed = 0;
+static int        stones_pr_hole = STONES_PR_HOLE;
 
 /*
  *  Player side and hole chosen by human player.
@@ -224,7 +225,7 @@ static void formFinish(void)
 
 static void ourInitGame(Player starter)
 {
-    initGame();
+    initGame(stones_pr_hole);
     player = starter;
     status = 0;
     fl_set_object_label(frm->playerB, playerName[0]);
@@ -376,10 +377,25 @@ void doQuit(FL_OBJECT *ob, long arg)
 }
 
 /**************************************************************************/
+#define stringify(a) #a
+#define stringize(a) stringify(a)
 
 int main(int argc, char *argv[])
 {
-    fl_initialize(&argc, argv, "XMancala", 0, 0);
+    static FL_CMD_OPT cmdopt [] = {
+        { "-stones", "*.stones", XrmoptionSepArg, 0 }};
+    static FL_resource res [] = {
+        { "stones", "XMancala", FL_INT, &stones_pr_hole,
+          stringize(STONES_PR_HOLE), 0 }};
+    fl_initialize(&argc, argv, "XMancala",
+                  cmdopt, sizeof(cmdopt) / sizeof(FL_CMD_OPT));
+    fl_get_app_resources(res, sizeof(res ) / sizeof(FL_resource));
+    if (stones_pr_hole < 1) {
+        fprintf(stderr,
+                "xmancala: the number of stones per hole must be "
+                "greater than zero\n");
+        return 1;
+    }
     formInit();
     formHandler();
     formFinish();
